function pd=mpheval(model,expr,varargin)
% MPHEVAL Evaluate expressions on node points
%
%   PD = MPHEVAL(MODEL,{e1,...,en},...) returns the post data PD for the
%   expressions e1,...,en.
%
%   The output value PD is a structure with fields expr, p, t, ve, unit and
%   the fields for data values.
%     - The field expr contains the expression name evaluated.
%     - For each expression e1,...,en a field with the name d1,...,dn is
%     added with the numerical values. The columns in the data value fields
%     correspond to node point coordinates in columns in p. The data
%     contains only the real part of complex-valued expressions.
%     - The field p contains node point coordinate information. The number
%     of rows in p is the number of space dimensions.
%     - The field t contains the indices to columns in p of a simplex mesh,
%     each column in t representing a simplex.
%     - The field ve contains indices to mesh elements for each node point.
%     - The field unit contains the list of the unit for each expression.
%
%   Valid property/value pairs include:
%   Property     Value/{Default}            Description
%   -----------------------------------------------------------------------
%   complexfun   'off' | {'on'}             Use complex-valued functions
%                                           with real input
%   complexout   'off' | {'on'}             Return complex values
%   dataonly     {'off'} | 'on'             Only return expression value
%   dataset      String {''}                Data set tag
%   edim         'point' | 'edge' |         Evaluate on elements with this
%                'boundary' | 'domain' |    dimension
%                integer {sdim}
%   matherr      'on' | {'off'}             Error for undefined operations
%                                           or expressions
%   outersolnum  Positive integer {1} |     Solution number for parametric
%                'end' | 'all'              sweep
%   pattern      {'lagrange'} | 'gauss'     Specifies if evaluation takes
%                                           place in Lagrange points or in
%                                           Gauss points.
%   phase        Scalar {0}                 Phase angle in degrees
%   recover      {'off'} | 'ppr' |          Accurate derivative recovery
%                'pprint'
%   refine       Integer {1}                Refinement of elements for
%                                           evaluation points
%   selection    Integer vector | String |  Set selection tag or entity
%                {'all'}                    number
%   smooth       none | {material} |        Smoothing setting
%                internal | everywhere | 
%                expression
%   smoothexpr   ''                         Expression used for smoothing
%   solnum       Integer vector |           Solution for evaluation
%                'end' | {'all'}
%   t            Double vector {''}         Time for evaluation
%   thresholdvalue Double                   Threshold value (0-1)
%   unit          String {''} |             Unit to use for the evaluation
%                 Cell array
%
%   The property edim is the space dimension to evaluate on. Instead of numbers 
%   one can use the strings 'domain', 'boundary', 'edge' or 'point'
%
%   The property solnum is used to select the inner solution number, e.g. when 
%   a parametric, eigenvalue or time-dependent solver has been used.
%   The property outersolnum is used to select the outer solution number, e.g. 
%   when a parametric sweep has been used in the study step node.
%
%   See the entry MPHEVAL in the LiveLink for MATLAB User's Guide for more
%   information about the property/values.
%
%
%   Example 1: Evaluate expression on node points
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%
%     % Evaluate the temperature at node points:
%     data = mpheval(model,'T')
%
%     % Evaluate both the total heat flux magnitude and the temperature:
%     data = mpheval(model,{'ht.tfluxMag', 'T'})
%
%     % Evaluate the temperature and return the data only:
%     data = mpheval(model,'T','dataonly','on')
%
%     % Evaluate the temperature at the node points in domain 2:
%     data = mpheval(model,'T','selection',2)
%
%     % Evaluate the temperature at the node points on boundary 7:
%     data = mpheval(model,'T','selection',7,'edim','boundary')
%
%     % Evaluate the temperature at second order Lagrange points:
%     data = mpheval(model,'T','refine',2)
%
%     % Evaluate the temperature at the Gauss points:
%     data = mpheval(model,'T','pattern','gauss')
%
%   Example 2: Evaluate expression using several solution dataset
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Evaluate the temperature at every time step computed with power set
%     % to 30:
%     data = mpheval(model,'T','dataset','dset2')
%
%     % Evaluate the temperature at the fifth time step:
%     data = mpheval(model,'T','dataset','dset2','solnum',5)
%
%     % Evaluate the temperature at 10.5 sec and 15.2 sec:
%     data = mpheval(model,'T','dataset','dset2','t',[10.5, 15.2])
%
%     % Evaluate the temperature at every time step computed with power set
%     % to 90:
%     data = mpheval(model,'T','dataset','dset2','outersolnum',3)
%
%   See also: mphevalglobalmatrix, mphevalpoint, mphevalpointmatrix,
%   mphglobal, mphint2, mphinterp

%   Copyright 2010-2022 COMSOL
