function varargout=mphevalpoint(model,expr,varargin)
% MPHEVALPOINT Evaluate expressions at geometry vertices
%
%   [V1,...,VN] = MPHEVALPOINT(MODEL,{E1,...,EN},...) returns the
%   results from evaluating the expressions E1,...,EN at the geometry
%   vertices. The values V1,...,VN can either be a cell array or a matrix
%   depending on the options.
%
%   [VAL1,...,VALN,UNIT] = MPHEVALPOINT(MODEL,{E1,...,EN},...) returns the
%   units of all the expression E1,...,EN in the cell array UNIT.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}            Description
%   -----------------------------------------------------------------------
%   dataset       String {''}                Data set tag
%   dataseries    {'none'} | 'mean' |        Data series operation
%                 'int' | 'max' | 'min' |    
%                 'rms' | 'std' | 'var'      
%   matrix        {'on'} | 'off'             Return a matrix if possible
%   minmaxobj     {'real'} | 'abs'           The value being treated if
%                                            Dataseries is set to max or min
%   outersolnum   Positive integer {1} |     Solution number for parametric
%                 'end' | 'all'              sweep
%   selection     Integer vector | String |  Set selection tag or entity
%                 {'all'}                    number
%   solnum        Integer vector |           Solution for evaluation
%                 'end' | {'all'}
%   squeeze       {'on'} | 'off'             Squeeze singleton dimensions
%   t             Double array {''}          Time of evaluation
%
%   The dataseries property is used to control any filtering of the
%   data series. The supported operations are: average ('mean'), integral
%   ('int'), maximum ('max'), minimum ('min'), root mean square ('rms'),
%   standard deviation ('std') and variamce ('var').
%
%
%   Example 1: Evaluate expression of a stationary problem
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%
%     % Evaluate the temperature on all geometry points:
%     T = mphevalpoint(model,'T')
%
%     % Evaluate the temperature on point 5:
%     T = mphevalpoint(model,'T','selection',5)
%
%     % Evaluate the temperature and the magnitude of the total heat flux
%     % on point 5:
%     [T, heatflux, unit] = mphevalpoint(model,{'T','ht.tfluxMag'},...
%        'selection',5)
%
%   Example 2: Evaluate expression using several solution dataset
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90',0);
%     % Run the study:
%     std.run;
%
%     % Evaluate the temperature at every time step computed
%     % with power set to 30:
%     T = mphevalpoint(model,'T','selection',5,'dataset','dset2')
%
%     % Evaluate the temperature at the seventh time step:
%     T = mphevalpoint(model,'T','selection',5,'dataset','dset2',...
%        'solnum',7)
%
%     % Evaluate the temperature at 10.5 sec:
%     T = mphevalpoint(model,'T','selection',5,'dataset','dset2','t',10.5)
%
%     % Evaluate the temperature on point 5 computed with power set to 90:
%     T = mphevalpoint(model,'T','selection',5,'dataset','dset2',...
%        'outersolnum',3)
%
%     % Evaluate the temperature average over all time steps:
%     T_avg = mphevalpoint(model,'T','selection',5,'dataset','dset2',...
%        'dataseries','average')
%
%   See also: mpheval, mphevalglobalmatrix, mphevalpointmatrix, mphglobal, 
%   mphint2, mphinterp

% Copyright 2012-2022 COMSOL
