function [obj,info,groups,formulas]=mphimage2geom(imagedata,level,varargin)
% MPHIMAGE2GEOM Convert image data to geometry
%
%   MODEL = MPHIMAGE2GEOM(IMAGEDATA, LEVEL, ...) converts the image 
%   contained in IMAGEDATA into a geometry which is returned in the model 
%   object MODEL.
%   The contour of the image is defined by the value LEVEL. IMAGEDATA must 
%   be a 2D matrix.
%
%   Valid property/value pairs include:
%   Property    Value / {Default}         Description
%   -----------------------------------------------------------------------
%   compose     {'on'} | 'off'            Create Compose nodes for 
%                                         overlapping solids
%   Curvetype   {'auto'} | 'polygon'      Type of curve object
%   Geom        {'geom1'} | geom node     Geometry creation
%   minarea     Value | {1}               Minimum area for interior curves
%                                         (in square pixels)
%   mindist     Value | {1}               Minimum distance between 
%                                         coordinates in curves (in pixels)
%   modeltag    {'Model'}                 Model tag in the COMSOL server
%   rectangle   'on' | {'off'}            Insert rectangle in the geometry
%   rtol        Value | {1e-3}            Relative tolerance for 
%                                         interpolation curves
%   scale       Value | {1}               Scale factor from pixels to 
%                                         geometry scale
%   type        'open' | 'closed' |       Type of geometry object
%               {'solid'}
%
%   The default curve types creates a geometry with the best suited 
%   geometrical primitives. For interior curves this is Interpolation Curves 
%   and for curves that are touching the perimeter of the image, Polygons is 
%   used.
%   To add the geometry created with MPHIMAGE2GEOM, specify the geometry
%   node with the property 'geom.'
%
%   Example 1:
%     % Create a set of point coordinates:
%     p = (peaks+7)*5;
%     % Display contour plot of the point data: 
%     figure(1);
%     [c,h] = contourf(p); clabel(c, h); colorbar
%     
%     % Create a geometry object following the contour made with point of
%     % value 50:
%     model = mphimage2geom(p, 50,'scale',1e-3);
%     figure(2); mphgeom(model)
%     % Create the same geometry scaled with a factor of 1e-3 and add insert
%     % it into a workplane of an existing 3D model: 
%     model = mphopen('model_tutorial_llmatlab');
%     wp1 = model.geom('geom1').feature.create('wp1', 'WorkPlane');
%     wp1.set('quickz', 1e-2);
%     mphimage2geom(p, 50,'scale',1e-3,'geom',wp1.geom);
%     mphgeom(model)
%
%   Example 2: Create a geometry using MRI data
%     % Load MRI data:
%     mri = load('mri');
%     im = mri.D(:,:,1,1);
%     figure(1); image(im)
%     % Create a geometry object following the contour made with point of
%     % value 30 and disregard objects with an area (in pixel) lower than 200:
%     model = mphimage2geom(im,30,'minarea',200);
%     figure(2); mphgeom(model)

% Copyright 2012-2022 COMSOL
