function varargout=mphinterp(model,expr,varargin)
% MPHINTERP Evaluate expressions in arbitrary points or data sets
%
%   [V1,...VN] = MPHINTERP(MODEL,{E1,...,EN},'COORD',COORD,...)
%   evaluates expressions E1,...EN at the coordinates specified in the
%   double matrix coord. Evaluation is supported only on Solution Data Sets.
%
%   [V1,...,VN] = MPHINTERP(MODEL,{E1,...,EN},'DATASET',DSETTAG,...)
%   evaluates expressions E1,...EN on the specifed data set DSETAG. In
%   this case the data set needs to be of a type that defines an
%   interpolation in itself, such as cut planes, revolve, etc...
%
%   [V1,...VN,UNIT] = MPHINTERP(MODEL,{E1,...,EN},...) returns in
%   addition the unit of the expressions.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}            Description
%   -----------------------------------------------------------------------
%   complexfun    'off' | {'on'}             Use complex-valued functions
%                                            with real input
%   complexout    'off' | {'on'}             Return complex values
%   coord         Double Array {''}          Coordinates for evaluation
%   coorderr      'off' | {'on'}             Give an error message if all
%                                            coordinates are outside the
%                                            geometry
%   dataset       String {''}                Data set tag
%   differential  'off' | {'on'}             Whether the expression should
%                                            be linearized at the
%                                            linearization point.
%   edim          'point' | 'edge' |         Element dimension for
%                 'boundary' | 'domain' |    evaluation
%                 integer {sdim}
%   evalmethod    {harmonic} | linpoint |    Applicable only for solutions
%                 lintotal | lintotalavg |   with a stored linearization
%                 lintotalrms | lintotalpeak point.
%   ext           Double between 0 and 1     Extrapolation distance
%                 {0.1}
%   matherr       {'off'} | 'on'             Error for undefined operation
%                                            or expressions
%   outersolnum   Positive integer {1} |	 Solution number for parametric
%                 'end' | 'all'              sweep
%   phase         Scalar {0}                 Phase angle in degrees
%   recover       {'off'} | 'ppr' |          Accurate derivative recovery
%                 'pprint'
%   selection     Positive Integer array |   Selection list
%                 String | {'all'}
%   solnum        Positive Integer array |   Inner solution for evaluation
%                 'end' | {'all'}
%   t             Double array {''}          Time of evaluation
%   unit          String {''} |              Unit to use for the evaluation
%                 Cell array
%
%   In case of multiple expression, if the unit property is defined with a
%   string the same unit will be used for both expressions. To use
%   different units, set the property with a cell array. In case of
%   unconsistent unit definition, the default unit will be used instead.
%
%   The differential property is applicable only if evalmethod is harmonic.
%
%   The property edim is the space dimension to evaluate on. Instead of
%   numbers one can use the strings 'domain', 'boundary', 'edge' or 'point'.
%
%   The property solnum is used to select the inner solution number, e.g.
%   when a parametric, eigenvalue or time-dependent solver has been used.
%   The property outersolnum is used to  select the outer solution number,
%   e.g. when a parametric sweep has been used in the study step node.
%
%   The extrapolation distance specify how much outside the mesh that the
%   interpolation searchs. The scale is in term of the local element size.
%
%   See the entry MPHINTERP in the LiveLink for MATLAB User's Guide for
%   more information about the property/values.
%
%   Example 1:
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a stationary study:
%     std = model.study.create('std');
%     std.feature.create('stat','Stationary');
%     % Run the study study:
%     std.run;
%
%     % Evaluate the temperature at given coordinates:
%     coord = [0,0,1e-2;0,0,1e-2;0,1e-2,1e-2];
%     T = mphinterp(model,'T','coord',coord)
%
%     % Evaluate both the temperature and the heat flux magnitude:
%     [T, tfluxMag] = mphinterp(model,{'T','ht.tfluxMag'},'coord',coord)
%
%     % Evaluate the temperature field on a structured grid:
%     x0 = [0,1e-2,2.5e-2,5e-2]; y0 = x0; z0 = [5e-3,1e-2,1.1e-2];
%     [x,y,z] = meshgrid(x0,y0,z0); xx = [x(:),y(:),z(:)]';
%     T = mphinterp(model,'T','coord',xx)
%
%     % Evaluate the temperature on boundary 7 using global coordinates:
%     x0 = [0,5e-3,1e-2]; y0 = x0; z0 = [1.1e-2];
%     [x,y,z] = meshgrid(x0,y0,z0); xx = [x(:),y(:),z(:)]';
%     T  = mphinterp(model,'T','coord',xx,'edim','boundary','selection',7)
%
%     % Evaluate the temperature and evaluation point global coordinates on
%     % boundary 7 using local coordinates:
%     s10 = [0,0.25,0.5]; s20 = [0,0.25,0.5];
%     [s1,s2] = meshgrid(s10,s20); ss = [s1(:),s2(:)]';
%     [x,y,z,T]  = mphinterp(model,{'x','y','z','T'},'coord',ss,...
%        'edim','boundary','selection',7)
%
%     % Modify the extrapolation distance for point coordinates outside of
%     % the geometry:
%     coord = [5e-2;5e-2;1.1e-2];
%     T = mphinterp(model,'T','coord',coord,'ext',0.5)
%
%     % Extract data using a cut line data set. First create the cutline
%     % data set, then evaluate the temperature field along the line:
%     cln = model.result.dataset.create('cln', 'CutLine3D');
%     cln.setIndex('genpoints','1e-2',1,0);
%     cln.setIndex('genpoints','1e-2',0,2);
%     cln.setIndex('genpoints','5e-2',1,0);
%     T = mphinterp(model,'T','dataset','cln')
%
%   Example 2: Evaluation including several solution
%     % Load model_tutorial_llmatlab.mph:
%     model = mphopen('model_tutorial_llmatlab');
%     % Create a study combining a parametric sweep and a transient
%     % study step:
%     std = model.study.create('std');
%     param = std.feature.create('param','Parametric');
%     time = std.feature.create('time','Transient');
%     % Set the time stepping and the parametric sweep parameters:
%     time.set('tlist', 'range(0,1,25)');
%     param.setIndex('pname','power',0).setIndex('plistarr','30 60 90', 0);
%     % Run the study:
%     std.run;
%
%     % Evaluate the temperature at every time step computed with power set
%     % to 30:
%     coord = [0 0 1e-2;0 0 1e-2;0 1e-2 1e-2];
%     T = mphinterp(model,'T','coord',coord,'dataset','dset2')
%
%     % Evaluate the temperature at the fifth time step:
%     T = mphinterp(model,'T','coord',coord,'dataset','dset2','solnum',5)
%
%     % Evaluate the temperature at 10.5 sec:
%     T = mphinterp(model,'T','coord',coord,'dataset','dset2','t',10.5)
%
%     % Evaluate the temperature at every time step computed with power set
%     % to 90:
%     T = mphinterp(model,'T','coord',coord,'dataset','dset2',...
%        'outersolnum',3)
%
%   See also: mpheval, mphevalglobalmatrix, mphevalpoint, mphevalpointmatrix,
%   mphglobal, mphint2

%   Copyright 2010-2022 COMSOL
