function info=mphxmeshinfo(model,varargin)
% MPHXHESHINFO Extract information about the extended mesh
%
%   INFO = MPHXMESHINFO(MODEL) extracts extended mesh information from the
%   active solution object.
%
%   INFO is a structure containing the following fields:
%   Field          Description
%   -----------------------------------------------------------------------
%   soltag         The solver node tag.
%   ndofs          The number of degrees of freedom.
%   fieldnames     The names of the field variables.
%   fieldndofs     The number of degrees of freedom per field variable.
%   meshtypes      The types of the mesh element.
%   geoms          The tag of the geometry node.
%   dofs           Structure with information about the degrees of freedom.
%   nodes          Structure with information about the nodes.
%   elements       Structure with information about each element type.
%
%   Valid property/value pairs include:
%   Property      Value/{Default}                  Description
%   -----------------------------------------------------------------------
%   soltag                                         Solution object tag
%   studysteptag                                   Study step node tag
%   meshcase      {'main'} | 'adaptionresidual' |  Mesh case tag
%                 multigrid mesh tag
%
%   Example 1:
%     %Load the base model MPH-file and compute the solution:
%     model = mphopen('model_tutorial_llmatlab.mph');
%     std = model.study.create('std');
%     std.feature.create('stat', 'Stationary');
%     std.run;
%
%     % Extract xmesh information:
%     info = mphxmeshinfo(model)
%     % Get the number of degrees of freedom and the nodes coordinates:
%     dofs = info.ndofs
%     coords = info.dofs.coords;
%     % Get the DOFs indices connected to the tetrahedron:
%     idx = info.elements.tet.dofs
%
%   Example 2: Retreive the xmesh information with several physics
%     % Load the base model MPH-file and compute the solution:
%     model = mphopen('model_tutorial_llmatlab.mph');
%     % Add a conductive media physics in the model and set the boundary
%     % conditions:
%     ec = model.physics.create('ec','ConductiveMedia','geom1');
%     ec.feature.create('gnd1','Ground',2).selection.set(3);
%     pot = ec.feature.create('pot','ElectricPotential',2);
%     pot.selection.set(7);
%     pot.set('V0',1,'50[mV]');
%     % Set Joule heating in the heat transfer equation:
%     hs = model.physics('ht').feature('hs1');
%     hs.set('heatSourceType',1,'generalSource');
%     hs.set('Q_src',1,'root.comp1.ec.Qh');
%     % Add a stationary studys step and compute the solution:
%     std = model.study.create('std');
%     std.feature.create('stat', 'Stationary');
%     std.run;
%
%     % Extract the extended mesh information:
%     info = mphxmeshinfo(model)
%     % Get the index of the nodes for element with the index 100:
%     idx_nodes = info.elements.tet.nodes(:,100)
%     % Get the index of the dofs for element with the index 100:
%     idx_dofs = info.elements.tet.dofs(:,100)
%     % Get the index of the variables names corrsponding to the dofs with
%     % the index idx_dofs:
%     idx_names = info.dofs.nameinds(idx_dofs);
%     % Find the dofnames index corresponding to the variable V:
%     idx_dofnames = find(strcmp(info.dofs.dofnames,'comp1.V'))-1;
%     % Get the list of dofs that correspond to the variable V:
%     idx = find(idx_names==idx_dofnames)
%     % Get the coordinates of the dofs corresponding to the dependent
%     % variable V that belong to element 100:
%     info.dofs.coords(:,idx_dofs(idx))
%
%   See also: mphgetu, mphmatrix, mphsolinfo, mphsolutioninfo

%   Copyright 2011-2022 COMSOL
